@@ -2,4 +2,4 @@
 from __future__ import unicode_literals
 
 from ._json_api import read_json, write_json, read_jsonl, write_jsonl
-from ._json_api import is_json_serializable
+from ._json_api import json_dumps, json_loads, is_json_serializable
